darkhistory.electrons.ics.ics_engloss_spectrum.engloss_spec_diff — DarkHistory documentation

# darkhistory.electrons.ics.ics_engloss_spectrum.engloss_spec_diff

`darkhistory.electrons.ics.ics_engloss_spectrum.` `engloss_spec_diff`(eleckineng, delta, T, as_pairs=False)

  Thomson ICS scattered electron energy loss spectrum, beta expansion.

  Parameters: | eleckineng : ndarray Incoming electron energy. delta : ndarray Energy lost by electron after one scatter (only positive values). T : float CMB temperature. as_pairs : bool If true, treats eleckineng and delta as a paired list: produces eleckineng.size == photeng.size values. Otherwise, gets the spectrum at each delta for each eleckineng, return an array of length eleckineng.size*delta.size.
  Returns: | ndarray dN/(dt d(delta)) of the scattered electrons, with abscissa delta.

#### Previous topic

darkhistory.electrons.ics.ics_engloss_spectrum.engloss_spec

#### Next topic

darkhistory.electrons.ics.ics_engloss_spectrum.engloss_spec_series

### This Page

Show Source